import { 
  select, 
  dsv, 
  scaleLinear, 
  max, 
  min,
  scaleBand,
  scaleTime,
  axisLeft,
  axisBottom} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  const xValue = d => Date.parse(d.year);
  const yValue = d => d.running_total;
  const year = d => d.year;
  const margin = {top:70, right:20, bottom:100, left:100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const yScale = scaleLinear()
    .domain([0,max(data, yValue)])
    .range([innerHeight, 0]);
  const xMin = min(data, xValue);
  const xMax = max(data, xValue);
  const xlen = max(data, year) - min(data, year);
  console.log(xlen);
  //const xScale = scaleBand()
    //.domain(data.map(xValue))
    //.range([0, innerWidth])
    //.padding(0.1);
  const xScale = scaleTime()
    .domain([xMin, xMax])
    .range([0, innerWidth]);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  g.append('g')
    .call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale).ticks(d3.timeYear.every(3)))
    .attr('transform', `translate(0,${innerHeight})`);
  
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('x', d => xScale(xValue(d)))
      .attr('height', d => innerHeight - (yScale(yValue(d))))
      .attr('width', '6')
      .attr('transform','scale(1,-1)')
      .attr('y', -innerHeight);
  g.append('text')
    .attr('y', -10)
    .attr('x', width/4)
    .text('Rebrickable Lego Sets by Year');
  g.append('text')
    .attr('y', innerHeight + margin.bottom/2)
    .attr('x', innerWidth-margin.left-10)
    .text('kratschan03')
};

dsv(',','data.csv').then(data => {
  data.forEach(d => {
    d.running_total = +d.running_total;
  });
  render(data);
});